==> mktcenter-service-threetree-1.0-20250915.094531-11-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktActivityCertificationPO {
    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private String activityName;

    private Date startTime;

    private Date endTime;

    private String province;

    private String city;

    private String district;

    private String detailedAddress;

    private String addressLon;

    private String addressLat;

    private String activityImg;

    private Integer issuanceType;

    private String certificationTypeIds;

    private String hostOrgCode;

    private String undertakingUnitName;

    private String activityDetail;

    private Integer state;

    private String onlineOrgCode;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName == null ? null : activityName.trim();
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province == null ? null : province.trim();
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city == null ? null : city.trim();
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district == null ? null : district.trim();
    }

    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress == null ? null : detailedAddress.trim();
    }

    public String getAddressLon() {
        return addressLon;
    }

    public void setAddressLon(String addressLon) {
        this.addressLon = addressLon == null ? null : addressLon.trim();
    }

    public String getAddressLat() {
        return addressLat;
    }

    public void setAddressLat(String addressLat) {
        this.addressLat = addressLat == null ? null : addressLat.trim();
    }

    public String getActivityImg() {
        return activityImg;
    }

    public void setActivityImg(String activityImg) {
        this.activityImg = activityImg == null ? null : activityImg.trim();
    }

    public Integer getIssuanceType() {
        return issuanceType;
    }

    public void setIssuanceType(Integer issuanceType) {
        this.issuanceType = issuanceType;
    }

    public String getCertificationTypeIds() {
        return certificationTypeIds;
    }

    public void setCertificationTypeIds(String certificationTypeIds) {
        this.certificationTypeIds = certificationTypeIds == null ? null : certificationTypeIds.trim();
    }

    public String getHostOrgCode() {
        return hostOrgCode;
    }

    public void setHostOrgCode(String hostOrgCode) {
        this.hostOrgCode = hostOrgCode == null ? null : hostOrgCode.trim();
    }

    public String getUndertakingUnitName() {
        return undertakingUnitName;
    }

    public void setUndertakingUnitName(String undertakingUnitName) {
        this.undertakingUnitName = undertakingUnitName == null ? null : undertakingUnitName.trim();
    }

    public String getActivityDetail() {
        return activityDetail;
    }

    public void setActivityDetail(String activityDetail) {
        this.activityDetail = activityDetail == null ? null : activityDetail.trim();
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getOnlineOrgCode() {
        return onlineOrgCode;
    }

    public void setOnlineOrgCode(String onlineOrgCode) {
        this.onlineOrgCode = onlineOrgCode == null ? null : onlineOrgCode.trim();
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}

==> mktcenter-service-threetree-1.0-20250915.100642-13-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktActivityCertificationPO {
    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private String activityName;

    private Date startTime;

    private Date endTime;

    private String province;

    private String city;

    private String district;

    private String detailedAddress;

    private String addressLon;

    private String addressLat;

    private String activityImg;

    private Integer issuanceType;

    private String certificationTypeIds;

    private String hostOrgCode;

    private String undertakingUnitName;

    private String activityDetail;

    private Integer state;

    private String onlineOrgCode;

    private Long viewCount;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName == null ? null : activityName.trim();
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province == null ? null : province.trim();
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city == null ? null : city.trim();
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district == null ? null : district.trim();
    }

    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress == null ? null : detailedAddress.trim();
    }

    public String getAddressLon() {
        return addressLon;
    }

    public void setAddressLon(String addressLon) {
        this.addressLon = addressLon == null ? null : addressLon.trim();
    }

    public String getAddressLat() {
        return addressLat;
    }

    public void setAddressLat(String addressLat) {
        this.addressLat = addressLat == null ? null : addressLat.trim();
    }

    public String getActivityImg() {
        return activityImg;
    }

    public void setActivityImg(String activityImg) {
        this.activityImg = activityImg == null ? null : activityImg.trim();
    }

    public Integer getIssuanceType() {
        return issuanceType;
    }

    public void setIssuanceType(Integer issuanceType) {
        this.issuanceType = issuanceType;
    }

    public String getCertificationTypeIds() {
        return certificationTypeIds;
    }

    public void setCertificationTypeIds(String certificationTypeIds) {
        this.certificationTypeIds = certificationTypeIds == null ? null : certificationTypeIds.trim();
    }

    public String getHostOrgCode() {
        return hostOrgCode;
    }

    public void setHostOrgCode(String hostOrgCode) {
        this.hostOrgCode = hostOrgCode == null ? null : hostOrgCode.trim();
    }

    public String getUndertakingUnitName() {
        return undertakingUnitName;
    }

    public void setUndertakingUnitName(String undertakingUnitName) {
        this.undertakingUnitName = undertakingUnitName == null ? null : undertakingUnitName.trim();
    }

    public String getActivityDetail() {
        return activityDetail;
    }

    public void setActivityDetail(String activityDetail) {
        this.activityDetail = activityDetail == null ? null : activityDetail.trim();
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getOnlineOrgCode() {
        return onlineOrgCode;
    }

    public void setOnlineOrgCode(String onlineOrgCode) {
        this.onlineOrgCode = onlineOrgCode == null ? null : onlineOrgCode.trim();
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}
